@@ -8,6 +8,16 @@ from __future__ import absolute_import
 import re
 import operator
 
+__all__ = [
+    'Rake',
+    'SmartStopList',
+    'FoxStopList',
+    'MySQLStopList',
+    'NLTKStopList',
+    'GoogleSearchStopList',
+    'RanksNLLongStopList',
+]
+
 
 def is_number(s):
     try:
@@ -53,7 +63,7 @@ def RanksNLStoplist():
 
 
 def load_stop_words(stop_word_file, regex):
-    with open(stop_word_file) as stop_word_file:
+    with open(stop_word_file, encoding='utf8') as stop_word_file:
         stop_words = re.split(regex, stop_word_file.read())
     return [word for word in stop_words if word not in ('', ' ')]  # filters empty string matches
 
